prebuilt_llvm_output

Function prebuilt_llvm_output 

pub fn prebuilt_llvm_output(
    builder: &Builder<'_>,
    target: TargetSelection,
) -> Option<LlvmOutput>
Attempt to return prebuilt LLVM output information, either downloaded from CI or through an externally provided LLVM.

It’s used e.g. to avoid busting caches during x.py check – if we’ve already built LLVM, it’s fine for us to not try to avoid doing so.

Calling this function should never attempt to checkout the LLVM submodule.