fn llvm_link_shared(config: &Config) -> boolExpand description
Determine whether llvm should be linked dynamically.
NOTE: This only contains the value from the config.
If you need to figure out the correct value for a specific LLVM instance, use
prebuilt_llvm_config instead.
This function is not a method on Config to discourage calling it from outside this module.